@@ -50,7 +50,7 @@ def error(message, exit_program=True, exit_code=1):
       exit_code (int):      Exit code to exit the program with, defaults to 1.
     """
     
-    _sys.stderr.write('\n'+_clr('ERROR: '+message, 'white', 'on_red', attrs=['bold'])+'\n\n')
+    _sys.stderr.write('\n'+_clr('ERROR: '+str(message), 'white', 'on_red', attrs=['bold'])+'\n\n')
     
     if exit_program: exit(exit_code)
     return
@@ -65,7 +65,7 @@ def warn(message, exit_program=False, exit_code=1):
       exit_code (int):      Exit code to exit the program with, defaults to 1.
     """
     
-    _sys.stderr.write('\n'+_clr('Warning: '+message, 'white', 'on_yellow', attrs=['bold'])+'\n\n')
+    _sys.stderr.write('\n'+_clr('Warning: '+str(message), 'white', 'on_yellow', attrs=['bold'])+'\n\n')
     
     if exit_program: exit(exit_code)
     return
